@@ -19,9 +19,9 @@ def build_made(
     z_score_x: bool = True,
     z_score_y: bool = True,
     hidden_features: int = 50,
-    num_blocks: int = 5,
     num_mixture_components: int = 10,
     embedding_net: nn.Module = nn.Identity(),
+    **kwargs,
 ) -> nn.Module:
     """Builds MADE p(x|y).
 
@@ -31,15 +31,17 @@ def build_made(
         z_score_x: Whether to z-score xs passing into the network.
         z_score_y: Whether to z-score ys passing into the network.
         hidden_features: Number of hidden features.
-        num_blocks: Number of MADE blocks.
         num_mixture_components: Number of mixture components.
         embedding_net: Optional embedding network for y.
+        kwargs: Additional arguments that are passed by the build function but are not
+            relevant for mades and are therefore ignored.
 
     Returns:
         Neural network.
     """
     x_numel = batch_x[0].numel()
-    y_numel = batch_y[0].numel()
+    # Infer the output dimensionality of the embedding_net by making a forward pass.
+    y_numel = embedding_net(batch_y[:1]).numel()
 
     if x_numel == 1:
         warn(f"In one-dimensional output space, this flow is limited to Gaussians")
@@ -57,7 +59,7 @@ def build_made(
         features=x_numel,
         hidden_features=hidden_features,
         context_features=y_numel,
-        num_blocks=num_blocks,
+        num_blocks=5,
         num_mixture_components=num_mixture_components,
         use_residual_blocks=True,
         random_mask=False,
@@ -80,6 +82,7 @@ def build_maf(
     hidden_features: int = 50,
     num_transforms: int = 5,
     embedding_net: nn.Module = nn.Identity(),
+    **kwargs,
 ) -> nn.Module:
     """Builds MAF p(x|y).
 
@@ -91,12 +94,15 @@ def build_maf(
         hidden_features: Number of hidden features.
         num_transforms: Number of transforms.
         embedding_net: Optional embedding network for y.
+        kwargs: Additional arguments that are passed by the build function but are not
+            relevant for maf and are therefore ignored.
 
     Returns:
         Neural network.
     """
     x_numel = batch_x[0].numel()
-    y_numel = batch_y[0].numel()
+    # Infer the output dimensionality of the embedding_net by making a forward pass.
+    y_numel = embedding_net(batch_y[:1]).numel()
 
     if x_numel == 1:
         warn(f"In one-dimensional output space, this flow is limited to Gaussians")
@@ -144,6 +150,7 @@ def build_nsf(
     hidden_features: int = 50,
     num_transforms: int = 5,
     embedding_net: nn.Module = nn.Identity(),
+    **kwargs,
 ) -> nn.Module:
     """Builds NSF p(x|y).
 
@@ -155,12 +162,15 @@ def build_nsf(
         hidden_features: Number of hidden features.
         num_transforms: Number of transforms.
         embedding_net: Optional embedding network for y.
+        kwargs: Additional arguments that are passed by the build function but are not
+            relevant for maf and are therefore ignored.
 
     Returns:
         Neural network.
     """
     x_numel = batch_x[0].numel()
-    y_numel = batch_y[0].numel()
+    # Infer the output dimensionality of the embedding_net by making a forward pass.
+    y_numel = embedding_net(batch_y[:1]).numel()
 
     if x_numel == 1:
         raise NotImplementedError
@@ -178,7 +188,7 @@ def build_nsf(
                             out_features=out_features,
                             hidden_features=hidden_features,
                             context_features=y_numel,
-                            num_blocks=2,
+                            num_blocks=num_blocks,
                             activation=relu,
                             dropout_probability=0.0,
                             use_batch_norm=False,
